| add_fields | R Documentation |
For environments, oClass instances and generator, add_fields is a wrapper for
list2env; it adds the objects in ... the environment if they are named.
For list and other objects, it behaves similar to appending ... as a list.
add_fields(x, ...)
x |
oClass instance, generator, environment, list, or other object |
... |
named objects to be added to |
object of same type as x or list
clown <- oClass("clown")
add_fields(clown, laugh = "haha", is_funny=TRUE)
clown$laugh
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.