| as.oClass | R Documentation |
This function takes any named object such as an environment, fully-named list, or an Instance
and converts it to an oClass generator function so that instances have
access to the fields in the named object. See oClass for details about the
arguments and functionality of the oClass generator.
as.oClass( x, name = NULL, inherit = NULL, portable = FALSE, hash = FALSE, formals = NULL, deep = TRUE, ... )
x |
object to be cloned and converted |
name |
character string describing the name of the class |
inherit |
oClass used as the |
portable |
logical indicating whether all inherited values should be copied into each instance |
hash |
logical indicating whether instances should use hashing, see |
formals |
list containing the formal arguments for the resulting generator function. These are passed to the |
deep |
logical. Should the object be deep-cloned? |
... |
named fields inherited by the class instance |
a function of class "ClassGenerator" with attributes describing each generated class instance
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.