| change_inherit | R Documentation |
This function takes twos oClass generator function and alters the first
so that it inherits the template and classes of the second. Existing instances will
inherit the objects contained in the new parent, but will not gain access to the S3
methods.
change_inherit(x, parent)
x |
oClass generator function |
parent |
oClass generator function from which |
oClass generator function
typist <- oClass("typist")
job <- oClass("job", hours = 40, pay=15)
typist <- change_inherit(typist, job)
typist$hours
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.