| clone | R Documentation |
A copy of all objects and attributes within an environment. If deep=TRUE,
all objects inside of x, including other environments, will also be deeply "cloned".
The global and base environments will not be cloned.
clone(x, deep = FALSE, ...) clone_attributes(x, deep = FALSE, cloned = NULL)
x |
environment of class |
deep |
logical for whether clone should be applied to all objects. |
... |
arguments passed to methods |
cloned |
environment containing references to environments that have already been cloned. This is passed to internal methods when |
environment of class "Instance"
clone_attributes: Clone the attributes of an object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.