| cpi_data | R Documentation |
This data set contains monthly observations of annualized price inflation from January 1949 until November 2021. Price inflation is calculated by taking the log difference between the CPI for Urban Consumers in one period and its value exactly one year earlier.
cpi_data
Data frame with 875 rows and 7 variables:
date in "YYYY-MM-DD" format
price inflation in decimal format
price inflation last month
price inflation two months ago
price inflation three months ago
price inflation six months ago
price inflation one year ago
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.