| Extract | R Documentation |
Operators acting on oClass generators and their instances.
## S3 method for class 'ClassGenerator' x$name ## S3 method for class 'ClassGenerator' x[[i, exact = TRUE, inherits = TRUE]] ## S3 replacement method for class 'ClassGenerator' x$name <- value ## S3 replacement method for class 'ClassGenerator' x[[name]] <- value ## S3 method for class 'Instance' x$name ## S3 method for class 'Instance' x[[i, exact = TRUE, inherits = TRUE]]
x |
object of class |
i, name |
character or symbol for |
exact |
logical controlling whether a partial match is acceptable. Defaults to |
inherits |
logical describing whether parent environments should be searched |
value |
new field value |
For oClass instances, `$` and `[` first search the instance environment for the object.
If no object is found, then all inherited objects are searched in order. Any object assigned to the instance
will be inserted into the instance's environment. These operators act on the underlying Class template environment
when applied to a Class generator.
Environment of class "Instance" or function of class "ClassGenerator"
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.